aboutsummaryrefslogtreecommitdiffstats
path: root/config/hypr/UserScripts
diff options
context:
space:
mode:
authorJa.KooLit <85185940+JaKooLit@users.noreply.github.com>2025-06-08 20:37:51 +0000
committerGitHub <noreply@github.com>2025-06-08 20:37:51 +0000
commitd06e73411295c453db2ee51b58579ce9566d8b4b (patch)
tree45e77c382c481a354392e405187ef7a9286a57c7 /config/hypr/UserScripts
parent1258a04a46d27cc1bc48fc57b4a68e1169fd7399 (diff)
Update WallpaperSelect.sh
Diffstat (limited to 'config/hypr/UserScripts')
-rwxr-xr-xconfig/hypr/UserScripts/WallpaperSelect.sh11
1 files changed, 5 insertions, 6 deletions
diff --git a/config/hypr/UserScripts/WallpaperSelect.sh b/config/hypr/UserScripts/WallpaperSelect.sh
index b5943586..47a8f2cd 100755
--- a/config/hypr/UserScripts/WallpaperSelect.sh
+++ b/config/hypr/UserScripts/WallpaperSelect.sh
@@ -98,19 +98,19 @@ menu() {
done
}
# Offer SDDM Sequioa Wallpaper Option (only for non-video wallpapers)
set_sddm_wallpaper() {
sleep 1
- sddm_sequoia="/usr/share/sddm/themes/sequoia_2"
+ sddm_simple="/usr/share/sddm/themes/simple_sddm_2"
- if [ -d "$sddm_sequoia" ]; then
+ if [ -d "$sddm_simple" ]; then
# Check if yad is running to avoid multiple notifications
if pidof yad >/dev/null; then
killall yad
fi
- if yad --info --text="Set current wallpaper as SDDM background?\n\nNOTE: This only applies to SEQUOIA SDDM Theme" \
+ if yad --info --text="Set current wallpaper as SDDM background?\n\nNOTE: This only applies to SIMPLE SDDM v2 Theme" \
--text-align=left \
--title="SDDM Background" \
--timeout=5 \
@@ -126,7 +126,7 @@ set_sddm_wallpaper() {
# Open terminal to enter password
$terminal -e bash -c "echo 'Enter your password to set wallpaper as SDDM Background'; \
- sudo cp -r $wallpaper_current '$sddm_sequoia/backgrounds/default' && \
+ sudo cp -r $wallpaper_current '$sddm_simple/Backgrounds/default' && \
notify-send -i '$iDIR/ja.png' 'SDDM' 'Background SET'"
fi
fi
@@ -236,4 +236,3 @@ if pidof rofi >/dev/null; then
fi
main
-
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
@@ -98,19 +98,19 @@ menu() {
done
}
-# Offer SDDM Sequioa Wallpaper Option (only for non-video wallpapers)
+# Offer SDDM Simple Wallpaper Option (only for non-video wallpapers)
set_sddm_wallpaper() {
sleep 1
pinapelz.com
homepage